@@ -110,7 +110,7 @@ class LocalCKAN(object):
         user = self._get_action('get_site_user')({'ignore_auth': True}, ())
         return user['name']
 
-    def call_action(self, action, data_dict=None, context=None):
+    def call_action(self, action, data_dict=None, context=None, apikey=None):
         """
         :param action: the action name, e.g. 'package_create'
         :param data_dict: the dict to pass to the action, defaults to {}
@@ -121,6 +121,10 @@ class LocalCKAN(object):
             data_dict = []
         if context is None:
             context = self.context
+        if apikey:
+            # FIXME: allow use of apikey to set a user in context?
+            raise CKANAPIError("LocalCKAN.call_action does not support "
+                "use of apikey parameter, use context['user'] instead")
         # copy dicts because actions may modify the dicts they are passed
         return self._get_action(action)(dict(context), dict(data_dict))
 
@@ -153,7 +157,7 @@ class RemoteCKAN(object):
         if request_fn:
             self._request_fn = request_fn
 
-    def call_action(self, action, data_dict=None, apikey=None):
+    def call_action(self, action, data_dict=None, context=None, apikey=None):
         """
         :param action: the action name, e.g. 'package_create'
         :param data_dict: the dict to pass to the action as JSON,
@@ -164,6 +168,9 @@ class RemoteCKAN(object):
         function will convert it back to an exception that matches the
         one the action function itself raised.
         """
+        if context:
+            raise CKANAPIError("RemoteCKAN.call_action does not support "
+                "use of context parameter, use apikey instead")
         url, data, headers = prepare_action(action, data_dict,
                                             apikey or self.apikey)
         status, response = self._request_fn(self.address + url, data, headers)
@@ -192,7 +199,7 @@ class TestAppCKAN(object):
         self.apikey = apikey
         self.action = ActionShortcut(self)
 
-    def call_action(self, action, data_dict=None, apikey=None):
+    def call_action(self, action, data_dict=None, context=None, apikey=None):
         """
         :param action: the action name, e.g. 'package_create'
         :param data_dict: the dict to pass to the action as JSON,
@@ -203,6 +210,9 @@ class TestAppCKAN(object):
         function will convert it back to an exception that matches the
         one the action function itself raised.
         """
+        if context:
+            raise CKANAPIError("TestAppCKAN.call_action does not support "
+                "use of context parameter, use apikey instead")
         url, data, headers = prepare_action(action, data_dict,
                                             apikey or self.apikey)
         r = self.test_app.post(url, data, headers, expect_errors=True)
